pub struct AsyncDb<T> { /* private fields */ }Expand description
Adapter that exposes an async database through the synchronous Database interface.
Implementations
Sourceimpl<T> AsyncDb<T>
impl<T> AsyncDb<T>
Sourcepub fn new(db: T) -> AsyncDb<T>
pub fn new(db: T) -> AsyncDb<T>
Creates a new async database adapter.
This captures the current Tokio runtime handle when one is available.
Sourcepub fn blocking(db: T) -> Option<AsyncDb<T>>
pub fn blocking(db: T) -> Option<AsyncDb<T>>
Creates a new async database adapter using the current Tokio runtime handle.
Returns None if no Tokio runtime is available or the current runtime is current-threaded.
Sourcepub const fn with_runtime(db: T, runtime: Runtime) -> AsyncDb<T>
pub const fn with_runtime(db: T, runtime: Runtime) -> AsyncDb<T>
Creates a new async database adapter with a Tokio runtime.
Sourcepub const fn with_handle(db: T, handle: Handle) -> AsyncDb<T>
pub const fn with_handle(db: T, handle: Handle) -> AsyncDb<T>
Creates a new async database adapter with a Tokio runtime handle.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the adapter and returns the wrapped database.