pub type StorageKeyMap<V> = HashMap<Uint<256, 4>, V, FbBuildHasher<32>>;Expand description
Type alias for a map with storage keys (U256) as keys.
Aliased Type
pub struct StorageKeyMap<V> { /* private fields */ }pub type StorageKeyMap<V> = HashMap<Uint<256, 4>, V, FbBuildHasher<32>>;Type alias for a map with storage keys (U256) as keys.
pub struct StorageKeyMap<V> { /* private fields */ }