pub struct AccountBal {
pub account_info: AccountInfoBal,
pub storage: StorageBal,
}Expand description
Account BAL structure.
Fields
account_info: AccountInfoBalAccount info bal.
storage: StorageBalStorage bal.
Implementations
Sourceimpl AccountBal
impl AccountBal
Sourcepub fn populate_account_info(
&self,
bal_index: BlockAccessIndex,
account: &mut AccountInfo,
) -> bool
pub fn populate_account_info( &self, bal_index: BlockAccessIndex, account: &mut AccountInfo, ) -> bool
Populate account from BAL. Return true if account info got changed
Sourcepub fn update(&mut self, bal_index: BlockAccessIndex, account: &Account)
pub fn update(&mut self, bal_index: BlockAccessIndex, account: &Account)
Extend account from another account.
Sourcepub fn try_from_alloy(
alloy_account: AccountChanges,
) -> Result<(Address, AccountBal), BytecodeDecodeError>
pub fn try_from_alloy( alloy_account: AccountChanges, ) -> Result<(Address, AccountBal), BytecodeDecodeError>
Create account from alloy account changes.
Sourcepub fn into_alloy_account(self, address: Address) -> AccountChanges
pub fn into_alloy_account(self, address: Address) -> AccountChanges
Consumes AccountBal and converts it into canonical EIP-7928
[AlloyAccountChanges].
The returned account changes are ordered deterministically: storage reads and storage changes are sorted lexicographically by slot key, changes within each storage slot are sorted by block access index, and balance, nonce, and code changes are sorted by block access index.
This matches the EIP-7928 ordering requirements: https://eips.ethereum.org/EIPS/eip-7928#ordering-uniqueness-and-determinism.
Methods from Deref<Target = AccountInfoBal>
Sourcepub fn populate_account_info(
&self,
bal_index: BlockAccessIndex,
account: &mut AccountInfo,
) -> bool
pub fn populate_account_info( &self, bal_index: BlockAccessIndex, account: &mut AccountInfo, ) -> bool
Populate account info from BAL. Return true if account info got changed
Sourcepub fn update(
&mut self,
index: BlockAccessIndex,
original: &AccountInfo,
present: &AccountInfo,
)
pub fn update( &mut self, index: BlockAccessIndex, original: &AccountInfo, present: &AccountInfo, )
Extend account info from another account info.
Sourcepub fn extend(&mut self, bal_account: AccountInfoBal)
pub fn extend(&mut self, bal_account: AccountInfoBal)
Extend account info from another account info.
Sourcepub fn balance_update(
&mut self,
bal_index: BlockAccessIndex,
original_balance: &Uint<256, 4>,
balance: Uint<256, 4>,
)
pub fn balance_update( &mut self, bal_index: BlockAccessIndex, original_balance: &Uint<256, 4>, balance: Uint<256, 4>, )
Update account balance in BAL.
Sourcepub fn nonce_update(
&mut self,
bal_index: BlockAccessIndex,
original_nonce: &u64,
nonce: u64,
)
pub fn nonce_update( &mut self, bal_index: BlockAccessIndex, original_nonce: &u64, nonce: u64, )
Update account nonce in BAL.
Sourcepub fn code_update(
&mut self,
bal_index: BlockAccessIndex,
original_code_hash: &FixedBytes<32>,
code_hash: FixedBytes<32>,
code: Bytecode,
)
pub fn code_update( &mut self, bal_index: BlockAccessIndex, original_code_hash: &FixedBytes<32>, code_hash: FixedBytes<32>, code: Bytecode, )
Update account code in BAL.