Struct BalWrites
pub struct BalWrites<T>{
pub writes: Vec<(u64, T)>,
}Expand description
Use to store values
If empty it means that this item was read from database.
Fields
writes: Vec<(u64, T)>List of writes with BalIndex.
Implementations
impl<T> BalWrites<T>
impl<T> BalWrites<T>
pub fn get_linear_search(&self, bal_index: u64) -> Option<T>
pub fn get_linear_search(&self, bal_index: u64) -> Option<T>
Linear search is used for small number of writes. It is faster than binary search.
pub fn force_update(&mut self, index: u64, value: T)
pub fn force_update(&mut self, index: u64, value: T)
Force insert a value into the BalWrites.
Check if last index is same as the index to insert. If it is, we override the value. If it is not, we push the value to the end of the vector.
No checks for original value is done. This is useful when we know that value is different.
pub fn update(&mut self, index: u64, original_value: &T, value: T)
pub fn update(&mut self, index: u64, original_value: &T, value: T)
Insert a value into the builder.
If BalIndex is same as last it will override the value.
pub fn update_with_key<K, F>(
&mut self,
index: u64,
original_subvalue: &K,
value: T,
f: F,
)
pub fn update_with_key<K, F>( &mut self, index: u64, original_subvalue: &K, value: T, f: F, )
Insert a value into the builder.
If BalIndex is same as last it will override the value.
Assumes that index is always greater than last one and that Writes are updated in proper order.