Function drop_in_place
pub unsafe fn drop_in_place<T, O>(_: BitPtr<Mut, T, O>)👎Deprecated:
this has no effect, and should not be called
pub unsafe fn drop_in_place<T, O>(_: BitPtr<Mut, T, O>)this has no effect, and should not be called